@@ -1,8 +1,25 @@
 #ifndef PyGSL_RNG_H
 #define PyGSL_RNG_H 1
-
+/*
+ * Author: Pierre Schnizer
+ *
+ * $Id: 
+ */
 #include <pygsl/intern.h>
 #include <gsl/gsl_rng.h>
+
+#undef __BEGIN_DECLS
+#undef __END_DECLS
+#ifdef __cplusplus
+# define __BEGIN_DECLS extern "C" {
+# define __END_DECLS }
+#else
+# define __BEGIN_DECLS /* empty */
+# define __END_DECLS /* empty */
+#endif
+__BEGIN_DECLS
+
+
 typedef struct {
   PyObject_HEAD
   gsl_rng * rng;
@@ -20,8 +37,11 @@ PyGSL_gsl_rng_from_pyobject(PyObject * object);
 (*(gsl_rng *  (*) (PyObject *)) PyGSL_API[PyGSL_gsl_rng_from_pyobject_NUM])
 #endif /* _PyGSL_API_MODULE */
 
-#define PyGSL_RNG_Check(op) \
-   ((op)->ob_type == (PyTypeObject *)PyGSL_API[PyGSL_RNG_ObjectType_NUM])
+#define PyGSL_RNG_Check(ob) \
+   (Py_TYPE(ob) == (PyTypeObject *)PyGSL_API[PyGSL_RNG_ObjectType_NUM])
+
+static const char _pygsl_rng_api_cap_name[] = "_pygsl_rng_api"; 
+#define _PyGSL_RNG_API_CAP _pygsl_rng_api_cap_name
 
 #define import_pygsl_rng() \
 { \
@@ -30,14 +50,17 @@ PyGSL_gsl_rng_from_pyobject(PyObject * object);
       (pygsl = PyImport_ImportModule("pygsl.rng"))         != NULL && \
       (md = PyModule_GetDict(pygsl))                       != NULL && \
       (c_api = PyDict_GetItemString(md, "_PYGSL_RNG_API")) != NULL && \
-      (PyCObject_Check(c_api))                                        \
+      (PyCapsule_CheckExact(c_api))				      \
      ) { \
-	 PyGSL_API = (void **)PyCObject_AsVoidPtr(c_api); \
+     PyGSL_API = (void **)PyCapsule_GetPointer(c_api,_PyGSL_RNG_API_CAP); \
    } else { \
         PyGSL_API = NULL; \
    } \
    /* fprintf(stderr, "PyGSL_API points to %p\n", (void *) PyGSL_API); */ \
 }
+
+__END_DECLS
+
 #endif  /* PyGSL_RNG_H */
 
 
