@@ -20,17 +20,17 @@ class TestPolyDD(unittest.TestCase):
         xa = Numeric.arange(100) / 100.0 * 2. * Numeric.pi
         ya = Numeric.sin(xa)
         self.dd = poly.poly_dd(xa, ya)
-        
-    def test_1_poly_dd(self):    
+
+    def test_1_poly_dd(self):
         assert(self.dd.eval(0) == 0.0)
-        
-    def test_2_poly_dd(self):    
+
+    def test_2_poly_dd(self):
         assert(Numeric.absolute(self.dd.eval(Numeric.pi)) < _eps)
 
-    def test_3_poly_dd(self):    
+    def test_3_poly_dd(self):
         assert(Numeric.absolute(self.dd.eval(Numeric.pi/2)-1)  < _eps)
 
-    def test_4_poly_dd(self):    
+    def test_4_poly_dd(self):
         c = self.dd.taylor(0.0)
 
 class TestQuadratic(unittest.TestCase):
@@ -45,7 +45,7 @@ class TestQuadratic(unittest.TestCase):
         assert(tmp == 2)
         assert(r1 == -2 or r2 == -2)
         assert(r1 == -1 or r2 == -1)
-        
+
     def test_complex(self):
         test = 0
         try:
@@ -55,7 +55,7 @@ class TestQuadratic(unittest.TestCase):
             if test == 0:
                 print(poly.complex_solve_quadratic(1,3,2))
         assert(tmp == 2)
-        
+
         assert(type(r1) == _complexType)
         assert(type(r2) == _complexType)
         assert(r1 == -2 or r2 == -2)
@@ -75,7 +75,7 @@ class TestCubic(unittest.TestCase):
         assert(r1 == -1 or r2 == -1 or r3 == -1)
         assert(r1 == -3 or r2 == -3 or r3 == -3)
 
-    def test_cubic_complex(self):        
+    def test_cubic_complex(self):
         tmp, r1, r2, r3 = poly.complex_solve_cubic(6,11,6)
         assert(tmp == 3)
         assert(type(r1) == _complexType)
@@ -83,7 +83,7 @@ class TestCubic(unittest.TestCase):
         assert(type(r3) == _complexType)
         assert(r1 == -2 or r2 == -2 or r3 == -2)
         assert(r1 == -1 or r2 == -1 or r3 == -1)
-        assert(r1 == -3 or r2 == -3 or r3 == -3) 
+        assert(r1 == -3 or r2 == -3 or r3 == -3)
 
 class TestCubicWorkspace(unittest.TestCase):
     def setUp(self):
@@ -97,16 +97,12 @@ class TestCubicWorkspace(unittest.TestCase):
         rs = pc.solve((2,3,1))
         r1 = rs[0]
         r2 = rs[1]
-        
+
         assert(iscomplex(r1))
         assert(iscomplex(r2))
         assert(r1 == -2 or r2 == -2)
         assert(r1 == -1 or r2 == -1)
-    
-def test():
-    unittest.main()
 
 
-    
 if __name__ == '__main__':
-    test()
+    unittest.main()
